@@ -24,14 +24,6 @@ PYPY = platform.python_implementation() == "PyPy"
 WINDOWS = platform.system() == "Windows"
 
 
-def bit_length(n):
-    return n.bit_length()
-
-
-def str_to_bytes(s):
-    return s.encode(a_good_encoding())
-
-
 def escape_unicode_characters(s):
     return codecs.encode(s, "unicode_escape").decode("ascii")
 
@@ -48,17 +40,6 @@ def int_to_byte(i):
     return bytes([i])
 
 
-def a_good_encoding():
-    return "utf-8"
-
-
-def to_unicode(x):
-    if isinstance(x, str):
-        return x
-    else:
-        return x.decode(a_good_encoding())
-
-
 def qualname(f):
     try:
         return f.__qualname__
@@ -190,16 +171,6 @@ def update_code_location(code, newfile, newlineno):
     return type(code)(*unpacked)
 
 
-def cast_unicode(s, encoding=None):
-    if isinstance(s, bytes):
-        return s.decode(encoding or a_good_encoding(), "replace")
-    return s
-
-
-def get_stream_enc(stream, default=None):
-    return getattr(stream, "encoding", None) or default
-
-
 # Under Python 2, math.floor and math.ceil returned floats, which cannot
 # represent large integers - eg `float(2**53) == float(2**53 + 1)`.
 # We therefore implement them entirely in (long) integer operations.
